declare function _exports(dht: import('../')): {
    /**
     * Announce to the network that we can provide the value for a given key
     *
     * @param {CID} key
     */
    provide(key: CID): Promise<void>;
    /**
     * Search the dht for up to `K` providers of the given CID.
     *
     * @param {CID} key
     * @param {Object} [options] - findProviders options
     * @param {number} [options.timeout=60000] - how long the query should maximally run, in milliseconds
     * @param {number} [options.maxNumProviders=5] - maximum number of providers to find
     * @returns {AsyncIterable<{ id: PeerId, multiaddrs: Multiaddr[] }>}
     */
    findProviders(key: CID, options?: {
        timeout?: number | undefined;
        maxNumProviders?: number | undefined;
    } | undefined): AsyncIterable<{
        id: PeerId;
        multiaddrs: Multiaddr[];
    }>;
};
export = _exports;
export type CID = import('multiformats/cid').CID;
export type PeerId = import('peer-id');
export type Multiaddr = import('multiaddr').Multiaddr;
//# sourceMappingURL=index.d.ts.map